function meshex(z,m0,dm,n)
% function meshex(z,m0,dm,n)  plots 3-d mesh from number of views
%    Argument List
% Argument   Gives
%    z      array of z elevations
%   m0      1st vector of view points
%   dm      change in view point vector
%   n       number of views
%   np      seconds to pause between views
% See section on mesh in the User's Guide
for k=1:n
   m=m0+(k-1)*dm;
   mesh(z)
   view(m)
   c1=sprintf('Angle of rotation about Z axis %8.2f degrees',m(1));
   c2=sprintf('Vertical elevation %8.2f degrees',m(2));
   text(5,0,-.4,c1)
   text(5,0,-.5,c2)
   pause(1)
end
